@@ -7,7 +7,7 @@
   Copyright 2015-2017 Joao Eriberto Mota Filho
   Copyright 2016      Stephen Thirlwall
   Copyright 2017      Antonio Quartulli
-  Copyright 2017      Ismael Luceno
+  Copyright 2017-2019 Ismael Luceno
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -36,15 +36,15 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 /* Main include file */
 
 #ifndef AXEL_AXEL_H
 #define AXEL_AXEL_H
 
-#include "config.h"
-
 #include <time.h>
 #include <ctype.h>
 #include <fcntl.h>
@@ -68,7 +68,16 @@
 #include <arpa/inet.h>
 #include <net/if.h>
 #include <pthread.h>
-#include "android-compat.h"
+#include "compat-android.h"
+#include "compat-bsd.h"
+#include "compat-ssl.h"
+
+/* GCC function attributes */
+#ifdef HAVE_FUNC_ATTRIBUTE_FORMAT
+#define PRINTF_FUNC(argn) __attribute__((format(__printf__, argn, argn+1)))
+#else
+#define PRINTF_FUNC(argn)
+#endif
 
 /* Internationalization */
 #ifdef ENABLE_NLS
@@ -94,6 +103,7 @@ typedef struct {
 typedef message_t url_t;
 typedef message_t if_t;
 
+#include "abuf.h"
 #include "conf.h"
 #include "tcp.h"
 #include "ftp.h"
@@ -121,8 +131,8 @@ typedef struct {
 	char filename[MAX_STRING];
 	double start_time;
 	int next_state, finish_time;
-	size_t bytes_done, start_byte, size;
-	int bytes_per_second;
+	off_t bytes_done, start_byte, size;
+	long long int bytes_per_second;
 	struct timespec delay_time;
 	int outfd;
 	int ready;
@@ -130,7 +140,7 @@ typedef struct {
 	url_t *url;
 } axel_t;
 
-axel_t *axel_new(conf_t *conf, int count, const void *url);
+axel_t *axel_new(conf_t *conf, int count, const search_t *urls);
 int axel_open(axel_t *axel);
 void axel_start(axel_t *axel);
 void axel_do(axel_t *axel);
@@ -138,14 +148,12 @@ void axel_close(axel_t *axel);
 void print_messages(axel_t *axel);
 
 double axel_gettime(void);
+ssize_t axel_rand64(uint64_t *);
+int axel_rnd_init(void);
 
+#define DN_MATCH_MALFORMED -1
+int dn_match(const char *hostname, const char *pat, size_t pat_len);
 
-#ifndef HAVE_STRLCAT
-size_t strlcat(char *, const char *, size_t);
-#endif /* HAVE_strlcat */
-
-#ifndef HAVE_STRLCPY
-size_t strlcpy(char *, const char *, size_t);
-#endif /* HAVE_STRLCPY */
+char *axel_size_human(char *dst, size_t len, size_t value);
 
 #endif				/* AXEL_AXEL_H */
