@@ -7,7 +7,8 @@
   Copyright 2016      Ivan Gimenez
   Copyright 2016      Stephen Thirlwall
   Copyright 2017      Antonio Quartulli
-  Copyright 2017      Ismael Luceno
+  Copyright 2017-2019 Ismael Luceno
+  Copyright 2019      Terry
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -36,10 +37,13 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 /* Configuration handling file */
 
+#include "config.h"
 #include "axel.h"
 
 /* Some nifty macro's.. */
@@ -48,7 +52,7 @@
 	else if (!strcmp(key, #name))	\
 		dst = &conf->name;
 
-int parse_interfaces(conf_t *conf, char *s);
+static int parse_interfaces(conf_t *conf, char *s);
 
 #ifdef __GNUC__
 __attribute__((format(scanf, 2, 3)))
@@ -72,6 +76,21 @@ axel_fscanf(FILE *fp, const char *format, ...)
 	return ret;
 }
 
+static int
+parse_progress_style(conf_t *conf, const char *value)
+{
+	if (!strcasecmp(value, "auto")) {/* no-op */}
+	else if (!strcasecmp(value, "alternative"))
+		conf->progress_style = AXEL_PROGRESS_STYLE_ALTERNATIVE;
+	else if (!strcasecmp(value, "classic"))
+		conf->progress_style = AXEL_PROGRESS_STYLE_CLASSIC;
+	else if (!strcasecmp(value, "percent"))
+		conf->progress_style = AXEL_PROGRESS_STYLE_PERCENTAGE;
+	else
+		fprintf(stderr, _("Unknown progress bar style \"%s\"\n"), value);
+	return 1;
+}
+
 static int
 parse_protocol(conf_t *conf, const char *value)
 {
@@ -80,7 +99,7 @@ parse_protocol(conf_t *conf, const char *value)
 	else if (strcasecmp(value, "ipv6") == 0)
 		conf->ai_family = AF_INET6;
 	else {
-		fprintf(stderr, _("Unknown protocol %s\n"), value);
+		fprintf(stderr, _("Unknown protocol \"%s\"\n"), value);
 		return 0;
 	}
 
@@ -151,7 +170,6 @@ conf_loadfile(conf_t *conf, const char *file)
 			KEY(buffer_size)
 			KEY(max_speed)
 			KEY(verbose)
-			KEY(alternate_output)
 			KEY(insecure)
 			KEY(no_clobber)
 			KEY(search_timeout)
@@ -159,12 +177,23 @@ conf_loadfile(conf_t *conf, const char *file)
 			KEY(search_amount)
 			KEY(search_top)
 		else
-			goto other_keys;
+			goto long_num_keys;
 
 		/* Save numeric option */
 		*((int *)dst) = atoi(value);
 		continue;
 
+		/* Long numeric options */
+ long_num_keys:
+		MATCH
+			KEY(max_speed)
+		else
+			goto other_keys;
+
+		/* Save numeric option */
+		*((unsigned long long *)dst) = strtoull(value, NULL, 10);
+		continue;
+
  other_keys:
 		/* Option defunct but shouldn't be an error */
 		if (strcmp(key, "speed_type") == 0)
@@ -172,6 +201,9 @@ conf_loadfile(conf_t *conf, const char *file)
 		else if (strcmp(key, "interfaces") == 0) {
 			if (parse_interfaces(conf, value))
 				continue;
+		} else if (strcmp(key, "progress_style") == 0) {
+			if (parse_progress_style(conf, value))
+				continue;
 		} else if (strcmp(key, "use_protocol") == 0) {
 			if (parse_protocol(conf, value))
 				continue;
@@ -230,7 +262,6 @@ conf_init(conf_t *conf)
 	conf->buffer_size = 5120;
 	conf->max_speed = 0;
 	conf->verbose = 1;
-	conf->alternate_output = 0;
 	conf->insecure = 0;
 	conf->no_clobber = 0;
 
@@ -251,6 +282,12 @@ conf_init(conf_t *conf)
 
 	conf->interfaces->next = conf->interfaces;
 
+	/* Detect if stdout is a tty, set the default indicator to alternate.
+	 * Otherwise, keep it to original. */
+	conf->progress_style = isatty(STDOUT_FILENO)
+		? AXEL_PROGRESS_STYLE_ALTERNATIVE
+		: AXEL_PROGRESS_STYLE_CLASSIC;
+
 	if ((s2 = getenv("http_proxy")) || (s2 = getenv("HTTP_PROXY")))
 		strlcpy(conf->http_proxy, s2, sizeof(conf->http_proxy));
 
@@ -287,6 +324,7 @@ conf_free(conf_t *conf)
 	free(conf->interfaces);
 }
 
+static
 int
 parse_interfaces(conf_t *conf, char *s)
 {
@@ -312,7 +350,6 @@ parse_interfaces(conf_t *conf, char *s)
 		return 1;
 	}
 
-	s[strlen(s) + 1] = 0;
 	conf->interfaces = iface = malloc(sizeof(if_t));
 	if (!conf->interfaces)
 		return 0;
