@@ -521,17 +521,18 @@ conn_info(conn_t *conn)
 	return 1;
 }
 
+/**
+ * Parse HTTP response status code, e.g. "HTTP/1.1 200 OK".
+ */
 int
 conn_info_status_get(char *msg, size_t size, conn_t *conn)
 {
 	if (is_proto_http(conn->proto)) {
 		char *p = conn->http->headers->p;
-		/* Skip protocol and code */
-		while (*p++ != ' ');
-		while (*p++ != ' ');
 		size_t len = strcspn(p, "\r\n");
-		if (len) {
-			strlcpy(msg, p, min(len + 1, size));
+		if (len > 13) {
+			/* Copy human-readable status only */
+			strlcpy(msg, p + 13, min(len - 12, size));
 			return conn->http->status;
 		}
 	}
